==> smart-testauto-framework-5.1.1-sources.jar: org/uitnet/testing/smartfwk/ui/core/objects/radio/RadioButtonGroup.java <==
/*
 * SmartTestAutoFramework
 * Copyright 2021 and beyond
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */
package org.uitnet.testing.smartfwk.ui.core.objects.radio;

import org.sikuli.script.Region;
import org.uitnet.testing.smartfwk.ui.core.SmartCucumberUiScenarioContext;
import org.uitnet.testing.smartfwk.ui.core.appdriver.SmartAppDriver;
import org.uitnet.testing.smartfwk.ui.core.commons.LocatorType;
import org.uitnet.testing.smartfwk.ui.core.commons.UIObjectType;
import org.uitnet.testing.smartfwk.ui.core.objects.UIObject;

/**
 * 
 * @author Madhav Krishna
 *
 */
public abstract class RadioButtonGroup extends UIObject {
	public RadioButtonGroup(LocatorType locatorType, String displayName) {
		super(locatorType, UIObjectType.radioButtonGroup, displayName);
	}

	public abstract RadioButtonGroupValidator getValidator(SmartAppDriver appDriver, Region region);

	public abstract RadioButtonGroupValidator getValidator(SmartCucumberUiScenarioContext scenarioContext,
			Region region);
}

==> smart-testauto-framework-6.0.0-sources.jar: org/uitnet/testing/smartfwk/ui/core/objects/radio/RadioButtonGroup.java <==
/*
 * SmartTestAutoFramework
 * Copyright 2021 and beyond
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */
package org.uitnet.testing.smartfwk.ui.core.objects.radio;

import org.sikuli.script.Region;
import org.uitnet.testing.smartfwk.SmartCucumberScenarioContext;
import org.uitnet.testing.smartfwk.ui.core.appdriver.SmartAppDriver;
import org.uitnet.testing.smartfwk.ui.core.commons.LocatorType;
import org.uitnet.testing.smartfwk.ui.core.commons.UIObjectType;
import org.uitnet.testing.smartfwk.ui.core.objects.UIObject;

/**
 * 
 * @author Madhav Krishna
 *
 */
public abstract class RadioButtonGroup extends UIObject {
	public RadioButtonGroup(LocatorType locatorType, String displayName) {
		super(locatorType, UIObjectType.radioButtonGroup, displayName);
	}

	public abstract RadioButtonGroupValidator getValidator(SmartAppDriver appDriver, Region region);

	public abstract RadioButtonGroupValidator getValidator(SmartCucumberScenarioContext scenarioContext,
			Region region);
}
